Utilities for dealing with BLE UUIDs, converting to and from their short formats.
Traits
- BleUuid
- An extension trait for
Uuidwhich provides BLE-specific methods.
Functions
- uuid_
from_ u16 - Convert a 16-bit BLE short UUID to a full 128-bit UUID by filling in the standard Bluetooth Base UUID.
- uuid_
from_ u32 - Convert a 32-bit BLE short UUID to a full 128-bit UUID by filling in the standard Bluetooth Base UUID.